==> haskell-errors-2.3.0-134-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 errors
version:              2.3.0
visibility:           public
id:                   errors-2.3.0-3hQlgwrUDV4Eg7FHUNftO
key:                  errors-2.3.0-3hQlgwrUDV4Eg7FHUNftO
license:              BSD-3-Clause
copyright:            2012, 2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".

    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.

category:             Control, Error Handling
abi:                  f78eb9238d358104eff9f5227767895e
exposed:              True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR

import-dirs:          /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-errors
hs-libraries:         HSerrors-2.3.0-3hQlgwrUDV4Eg7FHUNftO
depends:
    base-4.17.2.1 exceptions-0.10.5 safe-0.3.21-Jsj2ePpKDeG8OpB2hRbMdb
    text-2.0.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html:         /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.3.0-135-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 errors
version:              2.3.0
visibility:           public
id:                   errors-2.3.0-Aefjq2LTMoD4IIIM6Un0wI
key:                  errors-2.3.0-Aefjq2LTMoD4IIIM6Un0wI
license:              BSD-3-Clause
copyright:            2012, 2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".

    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.

category:             Control, Error Handling
abi:                  cb5c0184e02024ae20aafbcc0293058c
exposed:              True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR

import-dirs:          /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-errors
hs-libraries:         HSerrors-2.3.0-Aefjq2LTMoD4IIIM6Un0wI
depends:
    base-4.17.2.1 exceptions-0.10.5 safe-0.3.21-DqCLuIhxH5d2cQjqD83Qv7
    text-2.0.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html:         /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
